==> gromacs_2018.1.orig.tar.gz: gromacs-2018.1/src/gromacs/utility/typetraits.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2017, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares type traits
 *
 * \inlibraryapi
 * \ingroup module_utility
 */

#ifndef GMX_UTILITY_TYPETRAITS_H
#define GMX_UTILITY_TYPETRAITS_H

#include <type_traits>

namespace gmx
{

/*! \libinternal \brief
 * Is true if type is a std::integral_constant
 *
 * If the optional integral type is given, than it is only true for a
 * std::integral_constant of that integral type.
 *
 * \tparam T type to check
 * \tparam Int optional integral type
 */
template<typename T, typename Int = void>
struct isIntegralConstant : public std::false_type {};

template<typename Int, Int N>
struct isIntegralConstant<std::integral_constant<Int, N>, void> : public std::true_type {};

template<typename Int, Int N>
struct isIntegralConstant<std::integral_constant<Int, N>, Int> : public std::true_type {};

} // namespace gmx

#endif

==> gromacs_2021.4.orig.tar.gz: gromacs-2021.4/src/gromacs/utility/typetraits.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2017,2019, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares type traits
 *
 * \inlibraryapi
 * \ingroup module_utility
 */

#ifndef GMX_UTILITY_TYPETRAITS_H
#define GMX_UTILITY_TYPETRAITS_H

#include <type_traits>

namespace gmx
{

/*! \libinternal \brief
 * Is true if type is a std::integral_constant
 *
 * If the optional integral type is given, than it is only true for a
 * std::integral_constant of that integral type.
 *
 * \tparam T type to check
 * \tparam Int optional integral type
 */
template<typename T, typename Int = void>
struct isIntegralConstant : public std::false_type
{
};

template<typename Int, Int N>
struct isIntegralConstant<std::integral_constant<Int, N>, void> : public std::true_type
{
};

template<typename Int, Int N>
struct isIntegralConstant<std::integral_constant<Int, N>, Int> : public std::true_type
{
};

} // namespace gmx

#endif
